<template>
  <div class="gjfx">
    <div class="title">报警预警分析</div>
    <div class="list">
      <div class="item">
        <img src="~@/assets/img/xgzs/报警.png" alt="" />
        <div class="desc">
          <div class="number">
            <div class="value">{{ AlarmStatic }}</div>
            <div class="unit">处</div>
          </div>
          <div class="title">本月报警</div>
        </div>
      </div>
      <div class="item">
        <img src="~@/assets/img/xgzs/预警.png" alt="" />
        <div class="desc">
          <div class="number">
            <div class="value">{{ EarlyWarningStatic }}</div>
            <div class="unit">处</div>
          </div>
          <div class="title">本月预警</div>
        </div>
      </div>
    </div>
    <div class="title">报警预警数量变化趋势图</div>
    <div ref="chartRef" class="chart"></div>
  </div>
</template>

<script setup>
import * as echarts from "echarts";
import { ref, onMounted, reactive } from "vue";
import {
  queryAlarmStatic,
  queryEarlyWarningStatic,
  querySevenAlarmStatic,
} from "@/api/api.js";

const chartRef = ref(null);
onMounted(() => {
  // initChart()
  getData();
  getChartData();
});
const data = reactive({
  // chartX: [
  //   "13:00",
  //   "13:05",
  //   "13:10",
  //   "13:15",
  //   "13:20",
  //   "13:25",
  //   "13:30",
  //   "13:35",
  //   "13:40",
  //   "13:45",
  //   "13:50",
  //   "13:55",
  // ],
  chartX: [],
  alarmDayCount: [],
  warningDayCount: [],
  // chartY: [20, 10, 12, 14, 12, 16, 12, 20, 12, 19, 13, 15],
});

//当前视口宽度

// 换算方法
function nowSize(val, initWidth = 1920) {
  let nowClientWidth = document.documentElement.clientWidth;

  return val * (nowClientWidth / initWidth);
}

const AlarmStatic = ref(0);
const EarlyWarningStatic = ref(0);

async function getData() {
  const res1 = await queryAlarmStatic();
  if (res1.code == 200) {
    AlarmStatic.value = res1.result.alarmNumber;
    EarlyWarningStatic.value = res1.result.warningNumber;
  }
  // const res2 = await queryEarlyWarningStatic()
  // if (res1.code == 200 && res2.code == 200) {
  //   AlarmStatic.value = res1.result
  //   EarlyWarningStatic.value = res2.result
  // }
}
async function getChartData() {
  const res = await querySevenAlarmStatic();
  if (res.code == 200) {
    let chartX = [];
    data.alarmDayCount = [];
    data.warningDayCount = [];
    res.result.alarmDayCount.forEach((item) => {
      item.createTime = handleTime(item.createTime);
      chartX.push(item.createTime);
      data.alarmDayCount.push(item.num);
    });
    res.result.warningDayCount.forEach((item) => {
      item.createTime = handleTime(item.createTime);
      data.warningDayCount.push(item.num);
    });
    data.chartX = chartX;
    initChart();
    // if (typeof res.result === "object" && res.result !== null) {
    //   let chartX = Object.keys(res.result)
    //   let chartY = []
    //   chartX.forEach(item => {
    //     chartY.push(res.result[item])
    //   })
    //   data.chartX = chartX
    //   data.chartY = chartY
    //   // console.log(chartX, chartY)
    //   initChart()
    // }
  }
}

function handleTime(timeString) {
  return timeString.slice(4, 6) + "-" + timeString.slice(6, 8);
}

function initChart() {
  let myChart = echarts.init(chartRef.value);
  // 绘制图表
  myChart.setOption({
    tooltip: {
      trigger: "axis",
      textStyle: {
        fontSize: nowSize(12),
      },
      axisPointer: {
        lineStyle: {
          color: "#00B9FF",
        },
      },
    },
    grid: {
      top: "4%",
      left: "5%",
      right: "5%",
      bottom: "20%",
      containLabel: true,
    },
    xAxis: [
      {
        type: "category",
        boundaryGap: false,
        axisLine: {
          lineStyle: {
            color: "#FFFFFF",
          },
        },
        splitLine: {
          lineStyle: {
            color: "#14488F",
          },
        },
        axisLabel: {
          padding: [10, 0, 0, 0],
          interval: 0, //坐标刻度之间的显示间隔，默认就可以了（默认是不重叠）
          // rotate: 30, //调整数值改变倾斜的幅度（范围-90到90）
          textStyle: {
            fontSize: nowSize(12),
          },
          // formatter: function (value) {
          //   return value.slice(4)
          // },
        },
        data: data.chartX,
      },
      {
        axisPointer: {
          show: false,
        },
        axisLine: {
          lineStyle: {
            color: "#14488F",
          },
        },
        axisTick: {
          show: false,
          alignWithLabel: true,
        },
        position: "bottom",
      },
    ],
    yAxis: [
      {
        type: "value",
        axisLabel: {
          color: "#fff",
          textStyle: {
            fontSize: nowSize(12),
          },
        },
        scale: true,
        splitLine: {
          lineStyle: {
            color: "#14488F",
          },
        },
        minInterval: 1,
        // min: "0.1", // 最小值
      },
    ],
    series: [
      {
        name: "报警数量变化趋势图",
        type: "line",
        smooth: true,
        symbol: "circle",
        symbolSize: nowSize(5),
        showSymbol: false,
        lineStyle: {
          normal: {
            width: nowSize(2),
          },
        },
        areaStyle: {
          normal: {
            color: new echarts.graphic.LinearGradient(
              0,
              0,
              0,
              1,
              [
                {
                  offset: 0,
                  color: "rgba(0,185,255, 0.5)",
                },
                {
                  offset: 0.8,
                  color: "rgba(0,185,255, 0.3)",
                },
              ],
              false
            ),
            shadowColor: "rgba(0,185,255, 0.1)",
            shadowBlur: nowSize(10),
          },
        },
        itemStyle: {
          normal: {
            color: "rgb(0,136,212)",
            borderColor: "rgba(0,136,212,0.2)",
            borderWidth: nowSize(12),
          },
        },
        data: data.alarmDayCount,
      },
      {
        name: "预警数量变化趋势图",
        type: "line",
        smooth: true,
        symbol: "circle",
        symbolSize: nowSize(5),
        showSymbol: false,
        lineStyle: {
          normal: {
            width: nowSize(2),
          },
        },
        areaStyle: {
          normal: {
            color: new echarts.graphic.LinearGradient(
              0,
              0,
              0,
              1,
              [
                {
                  offset: 0,
                  color: "rgba(106,90,205, 0.5)",
                },
                {
                  offset: 0.8,
                  color: "rgba(106,90,205, 0.3)",
                },
              ],
              false
            ),
            shadowColor: "rgba(0,185,255, 0.1)",
            shadowBlur: nowSize(10),
          },
        },
        itemStyle: {
          normal: {
            color: "rgb(0,136,212)",
            borderColor: "rgba(0,136,212,0.2)",
            borderWidth: nowSize(12),
          },
        },
        data: data.warningDayCount,
      },
    ],
  });
  window.onresize = function () {
    //自适应大小
    myChart.resize();
  };
}
</script>

<style lang="less" scoped>
.gjfx {
  // position: absolute;
  // top: 497px;
  // left: 27px;
  width: 763px;
  height: 684px;
  background: url("~@/assets/img/xgzs/gjfx.png");
  background-size: 100% 100%;
  box-sizing: border-box;
  .title {
    padding: 40px;
    font-size: 30px;
    font-weight: bold;
    color: #ffffff;
    padding-bottom: 10px;
  }
  .list {
    margin-top: 30px;
    width: 100%;
    height: 100px;
    display: flex;
    justify-content: space-evenly;
    .item {
      display: flex;
      justify-content: space-around;
      width: 240px;
      img {
        width: 120px;
        height: 100px;
      }
      .desc {
        display: flex;
        flex-direction: column;
        justify-content: space-between;
        width: 110px;
      }
      .number {
        display: flex;
        justify-content: space-around;
        align-items: baseline;
        width: 100px;
        height: 34px;
        font-size: 50px;
        font-family: YouSheBiaoTiHei;
        font-weight: 400;
        color: #ffde2a;
        .unit {
          font-size: 24px;
          font-family: Source Han Sans CN;
          font-weight: 400;
          color: #ffffff;
        }
      }
      .title {
        padding: 0;
        font-size: 24px;
        font-family: Source Han Sans CN;
        font-weight: 400;
        color: #ffffff;
      }
    }
  }
  .chart {
    width: 98%;
    height: 400px;
  }
}
</style>
